summaryrefslogtreecommitdiffstats
path: root/ksirc/kstextview.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksirc/kstextview.h')
-rw-r--r--ksirc/kstextview.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/ksirc/kstextview.h b/ksirc/kstextview.h
index 4499f370..1ac273eb 100644
--- a/ksirc/kstextview.h
+++ b/ksirc/kstextview.h
@@ -482,7 +482,7 @@ public:
bool removeParag( const TextParagIterator &parag );
- void clearSelection( bool tqrepaint = false ); // ### re-consider the tqrepaint arg...
+ void clearSelection( bool repaint = false ); // ### re-consider the repaint arg...
TQString selectedText() const { return m_selectedText; }